@@ -75,7 +75,7 @@ class LBaaSSpecHandler(k8s_base.ResourceEventHandler):
     def _has_selector(self, service):
         return service['spec'].get('selector')
 
-    def _has_clusterip(sef, service):
+    def _has_clusterip(self, service):
         # ignore headless service, clusterIP is None
         return service['spec'].get('clusterIP') != 'None'
 
@@ -342,7 +342,8 @@ class LoadBalancerHandler(k8s_base.ResourceEventHandler):
                                                              p.port]
             except KeyError:
                 continue
-        current_targets = {(str(m.ip), m.port) for m in lbaas_state.members}
+        current_targets = {(str(m.ip), m.port, m.pool_id)
+                           for m in lbaas_state.members}
 
         for subset in endpoints.get('subsets', []):
             subset_ports = subset.get('ports', [])
@@ -358,10 +359,10 @@ class LoadBalancerHandler(k8s_base.ResourceEventHandler):
                     continue
                 for subset_port in subset_ports:
                     target_port = subset_port['port']
-                    if (target_ip, target_port) in current_targets:
-                        continue
                     port_name = subset_port.get('name')
                     pool = pool_by_tgt_name[port_name]
+                    if (target_ip, target_port, pool.id) in current_targets:
+                        continue
                     # TODO(apuimedo): Do not pass subnet_id at all when in
                     # L3 mode once old neutron-lbaasv2 is not supported, as
                     # octavia does not require it
