@@ -14,7 +14,6 @@
 #    under the License.
 
 import itertools
-import random
 import time
 
 from oslo_log import log as logging
@@ -22,12 +21,10 @@ from oslo_utils import excutils
 
 from kuryr_kubernetes import exceptions
 from kuryr_kubernetes.handlers import base
+from kuryr_kubernetes import utils
 
 LOG = logging.getLogger(__name__)
 
-DEFAULT_TIMEOUT = 180
-DEFAULT_INTERVAL = 3
-
 
 class Retry(base.EventHandler):
     """Retries handler on failure.
@@ -39,16 +36,13 @@ class Retry(base.EventHandler):
     `handler`, so the actual time spent within a single call to `Retry` may
     exceed the `timeout` depending on responsiveness of the `handler`.
 
-    `Retry` implements a variation of exponential backoff algorithm [1] and
-    ensures that there is a minimal time `interval` after the failed
     `handler` is retried for the same `event` (expected backoff E(c) =
     interval * 2 ** c / 2).
-
-    [1] https://en.wikipedia.org/wiki/Exponential_backoff
     """
 
     def __init__(self, handler, exceptions=Exception,
-                 timeout=DEFAULT_TIMEOUT, interval=DEFAULT_INTERVAL):
+                 timeout=utils.DEFAULT_TIMEOUT,
+                 interval=utils.DEFAULT_INTERVAL):
         self._handler = handler
         self._exceptions = exceptions
         self._timeout = timeout
@@ -73,28 +67,17 @@ class Retry(base.EventHandler):
                 raise
 
     def _sleep(self, deadline, attempt, exception):
-        now = time.time()
-        seconds_left = deadline - now
-
-        if seconds_left <= 0:
+        LOG.debug("Handler %s failed (attempt %s; %s)",
+                  self._handler, attempt, exceptions.format_msg(exception))
+        interval = utils.exponential_sleep(deadline, attempt,
+                                           self._interval)
+        if not interval:
             LOG.debug("Handler %s failed (attempt %s; %s), "
                       "timeout exceeded (%s seconds)",
                       self._handler, attempt, exceptions.format_msg(exception),
                       self._timeout)
             return 0
 
-        interval = random.randint(1, 2 ** attempt - 1) * self._interval
-
-        if interval > seconds_left:
-            interval = seconds_left
-
-        if interval < self._interval:
-            interval = self._interval
-
-        LOG.debug("Handler %s failed (attempt %s; %s), "
-                  "retrying in %s seconds",
-                  self._handler, attempt, exceptions.format_msg(exception),
-                  interval)
-
-        time.sleep(interval)
+        LOG.debug("Resumed after %s seconds. Retry handler %s", interval,
+                  self._handler)
         return interval
